class ProvidePhoneNumber {
	modal;
	laterModal;
	providePhoneNumberLaterButton;
	phoneNumberInput;
	agovInputPhoneNumberInput;
	agovInputRepeatPhoneNumberInput;

	constructor() {
		this.modal = document.querySelector('#modal');
		this.laterModal = document.querySelector('#laterModal');
		this.providePhoneNumberLaterButton = document.querySelector('#providePhoneNumberLaterButton');
		this.phoneNumberInput = document.querySelector('#phoneNumberInput');
		this.agovInputPhoneNumberInput = document.querySelector('#agovInputPhoneNumberInput');
		this.agovInputRepeatPhoneNumberInput = document.querySelector('#agovInputRepeatPhoneNumberInput');
		document.querySelector('#laterCheckbox').checked = true;

		this.providePhoneNumberLaterButton.addEventListener('click', () => {
			this.setVisible(this.laterModal);
		});
		document.querySelector('#laterModalBack').addEventListener('click', () => {
			this.resetValidation(this.agovInputPhoneNumberInput);
			this.setInvisible(this.laterModal);
		});
		document.querySelector('#repeatPhoneNumberModalBack').addEventListener('click', () => {
			this.setInvisible(this.modal);
		});
		document.querySelector('#repeatPhoneNumberModalContinue').addEventListener('click', () => {
			if (this.validateInput(this.agovInputRepeatPhoneNumberInput)) {
				this.evaluatePhoneNumbersAndSubmit();
			}
		});
		document.querySelector('#providePhoneNumberContinueButton').addEventListener('click', () => {
			if (this.validateInput(this.agovInputPhoneNumberInput)) {
				this.clearModalInput();
				this.resetValidation(this.agovInputRepeatPhoneNumberInput);
				this.showErrorBanner(false);
				this.setVisible(this.modal);
			}
		});
	}

	resetValidation(agovInput) {
		agovInput.validity = true;
	}

	validateInput(agovInput) {
		const innerInput = agovInput.querySelector('input');
		if (innerInput.value.trim().length === 0) {
			agovInput.supportingText = 0;
			agovInput.focus();
			agovInput.validity = false;
			return false;
		}
		return true;
	}

	setInvisible(modalElement) {
		window.utils.changeDisplay(modalElement, 'hidden', 'block');
	}

	setVisible(modalElement) {
		window.utils.changeDisplay(modalElement, 'block', 'hidden');
		const isMobile = !!/(iPhone|Android)/.test(window.navigator.userAgent);
		if (isMobile) {
			modalElement.classList.add('mobileDrawer');
			document.dispatchEvent(new Event('initDrawerPopup'));
		}
	}

	arePhoneNumbersEqual() {
		const phoneNumber = document.getElementById('phoneNumberInput').value.trim();
		const repeatedPhoneNumber = document.getElementById('mobile').value.trim();
		return phoneNumber === repeatedPhoneNumber;
	}

	evaluatePhoneNumbersAndSubmit() {
		if (this.arePhoneNumbersEqual()) {
			document.querySelector('#submit').click();
		}
		else {
			this.setInvisible(this.modal);
			this.showErrorBanner(true);
		}
	}

	clearModalInput() {
		const phoneNumberInput = document.getElementById('mobile');
		phoneNumberInput.value = '';
	}

	showErrorBanner(visible) {
		const errorBanner = document.getElementById('errorBanner');
		if (visible) {
			window.utils.changeDisplay(errorBanner, 'block', 'hidden');
		}
		else {
			window.utils.changeDisplay(errorBanner, 'hidden', 'block');
		}
	}
}

document.addEventListener('DOMContentLoaded', () => {
	document.dispatchEvent(new Event('initModal'));
	window.providePhoneNumber = new ProvidePhoneNumber();
});
